=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2006-07-27 23:45:25 +0000
+++ bzrlib/config.py	2006-08-06 23:35:09 +0000
@@ -167,7 +167,8 @@
     
         Something similar to 'Martin Pool <mbp@sourcefrog.net>'
         
-        $BZREMAIL can be set to override this, then
+        $BZR_EMAIL can be set to override this (as well as the
+        deprecated $BZREMAIL), then
         the concrete policy type is checked, and finally
         $EMAIL is examined.
         If none is found, a reasonable default is (hopefully)
@@ -175,8 +176,12 @@
     
         TODO: Check it's reasonably well-formed.
         """
+        v = os.environ.get('BZR_EMAIL')
+        if v:
+            return v.decode(bzrlib.user_encoding)
         v = os.environ.get('BZREMAIL')
         if v:
+            warning('BZREMAIL is deprecated in favor of BZR_EMAIL. Please update your configuration.')
             return v.decode(bzrlib.user_encoding)
     
         v = self._get_user_id()

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-07-31 16:29:15 +0000
+++ bzrlib/tests/__init__.py	2006-08-06 23:35:09 +0000
@@ -593,7 +593,7 @@
         new_env = {
             'HOME': os.getcwd(),
             'APPDATA': os.getcwd(),
-            'BZREMAIL': None,
+            'BZR_EMAIL': None,
             'EMAIL': None,
         }
         self.__old_env = {}

=== modified file 'bzrlib/tests/blackbox/test_non_ascii.py'
--- bzrlib/tests/blackbox/test_non_ascii.py	2006-07-21 04:02:14 +0000
+++ bzrlib/tests/blackbox/test_non_ascii.py	2006-08-06 23:35:09 +0000
@@ -31,20 +31,20 @@
 
     def setUp(self):
         super(TestNonAscii, self).setUp()
-        self._orig_email = os.environ.get('BZREMAIL', None)
+        self._orig_email = os.environ.get('BZR_EMAIL', None)
         self._orig_encoding = bzrlib.user_encoding
 
         bzrlib.user_encoding = self.encoding
         email = self.info['committer'] + ' <joe@foo.com>'
-        os.environ['BZREMAIL'] = email.encode(bzrlib.user_encoding)
+        os.environ['BZR_EMAIL'] = email.encode(bzrlib.user_encoding)
         self.create_base()
 
     def tearDown(self):
         if self._orig_email is not None:
-            os.environ['BZREMAIL'] = self._orig_email
+            os.environ['BZR_EMAIL'] = self._orig_email
         else:
-            if os.environ.get('BZREMAIL', None) is not None:
-                del os.environ['BZREMAIL']
+            if os.environ.get('BZR_EMAIL', None) is not None:
+                del os.environ['BZR_EMAIL']
         bzrlib.user_encoding = self._orig_encoding
         super(TestNonAscii, self).tearDown()
 

=== modified file 'bzrlib/tests/blackbox/test_whoami.py'
--- bzrlib/tests/blackbox/test_whoami.py	2006-07-12 16:29:39 +0000
+++ bzrlib/tests/blackbox/test_whoami.py	2006-07-14 09:05:49 +0000
@@ -42,8 +42,11 @@
         b = bzrlib.branch.Branch.open('.')
         b.get_config().set_user_option('email',
                                        'Branch Identity <branch@identi.ty>')
-        bzr_email = os.environ.get('BZREMAIL')
+        bzr_email = os.environ.get('BZR_EMAIL')
         if bzr_email is not None:
+            del os.environ['BZR_EMAIL']
+        bzremail = os.environ.get('BZREMAIL')
+        if bzremail is not None:
             del os.environ['BZREMAIL']
         try:
             whoami = self.run_bzr("whoami")[0]
@@ -53,23 +56,31 @@
 
             # Verify that the environment variable overrides the value 
             # in the file
-            os.environ['BZREMAIL'] = 'Different ID <other@environ.ment>'
+            os.environ['BZR_EMAIL'] = 'Different ID <other@environ.ment>'
             whoami = self.run_bzr("whoami")[0]
             self.assertEquals('Different ID <other@environ.ment>\n', whoami)
             whoami_email = self.run_bzr("whoami", "--email")[0]
             self.assertEquals('other@environ.ment\n', whoami_email)
+            del os.environ['BZR_EMAIL']
+            os.environ['BZREMAIL'] = 'Yet Another ID <yetother@environ.ment>'
+            whoami, warn = self.run_bzr("whoami")
+            self.assertEquals('Yet Another ID <yetother@environ.ment>\n', whoami)
+            self.assertTrue(len(warn) > 0)
+            del os.environ['BZREMAIL']
         finally:
             if bzr_email is not None:
-                os.environ['BZREMAIL'] = bzr_email
+                os.environ['BZR_EMAIL'] = bzr_email
+            if bzremail is not None:
+                os.environ['BZREMAIL'] = bzremail
 
     def test_whoami_utf8(self):
         """verify that an identity can be in utf-8."""
         wt = self.make_branch_and_tree('.')
         self.run_bzr('whoami', u'Branch Identity \u20ac <branch@identi.ty>',
                      encoding='utf-8')
-        bzr_email = os.environ.get('BZREMAIL')
+        bzr_email = os.environ.get('BZR_EMAIL')
         if bzr_email is not None:
-            del os.environ['BZREMAIL']
+            del os.environ['BZR_EMAIL']
         try:
             whoami = self.run_bzr("whoami", encoding='utf-8')[0]
             self.assertEquals('Branch Identity \xe2\x82\xac ' +
@@ -79,7 +90,7 @@
             self.assertEquals('branch@identi.ty\n', whoami_email)
         finally:
             if bzr_email is not None:
-                os.environ['BZREMAIL'] = bzr_email
+                os.environ['BZR_EMAIL'] = bzr_email
 
     def test_whoami_ascii(self):
         """
@@ -90,9 +101,9 @@
         b = bzrlib.branch.Branch.open('.')
         b.get_config().set_user_option('email', u'Branch Identity \u20ac ' +
                                        '<branch@identi.ty>')
-        bzr_email = os.environ.get('BZREMAIL')
+        bzr_email = os.environ.get('BZR_EMAIL')
         if bzr_email is not None:
-            del os.environ['BZREMAIL']
+            del os.environ['BZR_EMAIL']
         try:
             whoami = self.run_bzr("whoami", encoding='ascii')[0]
             self.assertEquals('Branch Identity ? <branch@identi.ty>\n', whoami)
@@ -101,7 +112,7 @@
             self.assertEquals('branch@identi.ty\n', whoami_email)
         finally:
             if bzr_email is not None:
-                os.environ['BZREMAIL'] = bzr_email
+                os.environ['BZR_EMAIL'] = bzr_email
 
     def test_warning(self):
         """verify that a warning is displayed if no email is given."""

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2006-07-21 19:49:48 +0000
+++ bzrlib/tests/test_config.py	2006-08-06 23:35:09 +0000
@@ -750,8 +750,8 @@
         my_config.branch.control_files.email = "John"
         self.assertEqual("John", my_config._get_user_id())
 
-    def test_BZREMAIL_OVERRIDES(self):
-        os.environ['BZREMAIL'] = "Robert Collins <robertc@example.org>"
+    def test_BZR_EMAIL_OVERRIDES(self):
+        os.environ['BZR_EMAIL'] = "Robert Collins <robertc@example.org>"
         branch = FakeBranch()
         my_config = config.BranchConfig(branch)
         self.assertEqual("Robert Collins <robertc@example.org>",

=== modified file 'doc/configuration.txt'
--- doc/configuration.txt	2006-07-30 07:23:36 +0000
+++ doc/configuration.txt	2006-08-06 23:35:09 +0000
@@ -100,7 +100,7 @@
 ------
 The path of the editor that you wish to use if *bzr commit* is run without
 a commit log message. This setting is trumped by the environment variables
-$BZREDITOR or $EDITOR.
+$BZR_EDITOR or $EDITOR.
 
 check_signatures
 ----------------

=== modified file 'tools/doc_generate/autodoc_man.py'
--- tools/doc_generate/autodoc_man.py	2006-07-31 06:13:23 +0000
+++ tools/doc_generate/autodoc_man.py	2006-08-06 23:35:09 +0000
@@ -180,7 +180,7 @@
 .B "%(bzrcmd)s"
 is to look for external command.
 .TP
-.I "BZREMAIL"
+.I "BZR_EMAIL"
 E-Mail address of the user. Overrides default user config.
 .TP
 .I "EMAIL"

=== modified file 'tools/doc_generate/autodoc_rstx.py'
--- tools/doc_generate/autodoc_rstx.py	2006-07-31 06:13:23 +0000
+++ tools/doc_generate/autodoc_rstx.py	2006-08-06 23:35:09 +0000
@@ -190,7 +190,7 @@
 **BZRPATH**
                 Path where **%(bzrcmd)s** is to look for external command.
 
-**BZREMAIL**
+**BZR_EMAIL**
                 E-Mail address of the user. Overrides default user config.
 
 **EMAIL**

